# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.
"""empty message

Revision ID: fc480c87706c
Revises: ('4451805bbaa1', '1d9e835a84f9')
Create Date: 2018-07-22 11:50:54.174443

"""

# revision identifiers, used by Alembic.
revision = "fc480c87706c"
down_revision = ("4451805bbaa1", "1d9e835a84f9")


def upgrade():
    pass


def downgrade():
    pass
